<?php
/**
 * A filter chain for processing network packages (or better messages)
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class PackageFilterChain extends FilterChain {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$chainInstance	An instance of this class
	 */
	public static final function createPackageFilterChain () {
		// Get a new instance
		$chainInstance = new PackageFilterChain();

		// Return the prepared instance
		return $chainInstance;
	}

	/**
	 * Processes the given raw message content through all filters
	 *
	 * @param	$messageContent		Raw message content
	 * @param	$packageInstance	An instance of a Receivable class
	 * @return	void
	 * @todo	This may be slow if a message with a lot tags arrived
	 */
	public function processMessage ($messageContent, Receivable $packageInstance) {
		// Get all filters and "run" them
		foreach ($this->getFilters() as $filterInstance) {
			// Try to process it
			try {
				$filterInstance->processMessage($messageContent, $packageInstance);
			} catch (FilterChainException $e) {
				// This exception can be thrown to just skip any further processing
				self::createDebugInstance(__CLASS__)->debugOutput('Failed to execute lase filter ' . $filterInstance->__toString() . ': ' . $e->getMessage());
				break;
			}
		} // END - foreach
	}
}

// [EOF]
?>
