<?php
/**
 * An active node state class
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class NodeActiveState extends BaseNodeState implements Stateable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set state name
		$this->setStateName('active');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$stateInstance	An instance of a Stateable class
	 */
	public static final function createNodeActiveState () {
		// Get new instance
		$stateInstance = new NodeActiveState();

		// Get node instance and set 'active' flag
		NodeObjectFactory::createNodeInstance()->enableIsActive();

		// Return the prepared instance
		return $stateInstance;
	}

	/**
	 * State change for if the node got announced to it's upper hubs
	 *
	 * @return	void
	 */
	public function nodeAnnouncingToUpperHubs () {
		// Create the new state instance
		NodeStateFactory::createNodeStateInstanceByName('announcing');
	}

	/**
	 * State change for if the node has just connected to itself and
	 * node/session id are both equal. The self-connect means that
	 * the node possibly reachable from outside. This may require
	 * confirmation by other peers.
	 *
	 * @return	void
	 * @todo	We might want to move some calls to this method to fill it with life
	 */
	public function nodeHasSelfConnected () {
		// Create the new state instance
		NodeStateFactory::createNodeStateInstanceByName('reachable');
	}
}

// [EOF]
?>
